@@ -476,9 +476,13 @@ class BaseRester(Generic[T]):
         num_docs_needed = min((max_pages * chunk_size), total_num_docs)
 
         # Setup progress bar
-        pbar = tqdm(
-            desc=f"Retrieving {self.document_model.__name__} documents",  # type: ignore
-            total=num_docs_needed,
+        pbar = (
+            tqdm(
+                desc=f"Retrieving {self.document_model.__name__} documents",  # type: ignore
+                total=num_docs_needed,
+            )
+            if not MAPIClientSettings().MUTE_PROGRESS_BARS
+            else None
         )
 
         initial_data_length = len(total_data["data"])
@@ -487,15 +491,18 @@ class BaseRester(Generic[T]):
         if initial_data_length >= num_docs_needed or num_chunks == 1:
             new_total_data = copy(total_data)
             new_total_data["data"] = total_data["data"][:num_docs_needed]
-            pbar.update(num_docs_needed)
-            pbar.close()
+
+            if pbar is not None:
+                pbar.update(num_docs_needed)
+                pbar.close()
             return new_total_data
 
         # otherwise, prepare to paginate in parallel
         if chunk_size is None:
             raise ValueError("A chunk size must be provided to enable pagination")
 
-        pbar.update(initial_data_length)
+        if pbar is not None:
+            pbar.update(initial_data_length)
 
         # Warning to select specific fields only for many results
         if criteria.get("all_fields", False) and (total_num_docs / chunk_size > 10):
@@ -546,7 +553,8 @@ class BaseRester(Generic[T]):
         if "meta" in data:
             total_data["meta"]["time_stamp"] = data["meta"]["time_stamp"]
 
-        pbar.close()
+        if pbar is not None:
+            pbar.close()
 
         return total_data
 
@@ -587,7 +595,11 @@ class BaseRester(Generic[T]):
                 params_gen, MAPIClientSettings().NUM_PARALLEL_REQUESTS
             ):
 
-                future = executor.submit(self.session.get, **params)
+                future = executor.submit(
+                    self._submit_request_and_process,
+                    use_document_model=use_document_model,
+                    **params,
+                )
                 setattr(future, "crit_ind", params_ind)
                 futures.add(future)
                 params_ind += 1
@@ -597,35 +609,42 @@ class BaseRester(Generic[T]):
                 finished, futures = wait(futures, return_when=FIRST_COMPLETED)
 
                 for future in finished:
-                    response = future.result()
-                    data, subtotal = self._handle_response(response, use_document_model)
+                    data, subtotal = future.result()
                     if progress_bar is not None:
                         progress_bar.update(len(data["data"]))
                     return_data.append((data, subtotal, future.crit_ind))  # type: ignore
 
                 # Populate more futures to replace finished
                 for params in itertools.islice(params_gen, len(finished)):
-                    new_future = executor.submit(self.session.get, **params)
+                    new_future = executor.submit(
+                        self._submit_request_and_process,
+                        use_document_model=use_document_model,
+                        **params,
+                    )
                     setattr(new_future, "crit_ind", params_ind)
                     futures.add(new_future)
                     params_ind += 1
 
         return return_data
 
-    def _handle_response(
-        self, response: requests.Response, use_document_model: bool
+    def _submit_request_and_process(
+        self, url: str, verify: bool, params: dict, use_document_model: bool
     ) -> Tuple[Dict, int]:
         """
-        Handles resolved requests.
+        Submits GET request and handles the response.
 
         Arguments:
-            response: response from request
+            url: URL to send request to
+            verify: whether to verify the server's TLS certificate
+            params: dictionary of parameters to send in the request
             use_document_model: if None, will defer to the self.use_document_model attribute
 
         Returns:
             Tuple with data and total number of docs in matching the query in the database.
         """
 
+        response = self.session.get(url=url, verify=verify, params=params)
+
         if response.status_code == 200:
 
             if self.monty_decode:
@@ -769,6 +788,7 @@ class BaseRester(Generic[T]):
         A generic search method to retrieve documents matching specific parameters.
 
         Arguments:
+            mute (bool): Whether to mute progress bars.
             num_chunks (int): Maximum number of chunks of data to yield. None will yield all possible.
             chunk_size (int): Number of data entries per chunk.
             all_fields (bool): Set to False to only return specific fields of interest. This will
